@@ -51,8 +51,8 @@ class genetic_data_handler:
         categories list: A numpy array object
         :rtype: np.ndarray
         """
-        if self.subjects is None:
-            print("Please initialize with a chromosome and read the binary data first")
+        if self.subjects_list is None:
+            print("Please initialize Module")
             return None
 
         else:
@@ -99,7 +99,7 @@ class genetic_data_handler:
         self.chromosome=chr_num
         print("Genetic handler object initialized with chromosome")
 
-    def get_binary_data(self, subject_list):
+    def get_binary_data(self):
         genetic_data_output = []
         for chr_num in ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13"]:
 
@@ -107,7 +107,7 @@ class genetic_data_handler:
                                          genetic_data_path + "bim_files/" + "ukb_snp_chr" + chr_num + "_v2.bim",
                                          genetic_data_path + "fam_files/" + "ukb22418_c" + chr_num + "_b0_v2_s488176.fam",verbose=True)
             genetic_df = genetic_df.set_index({"variant": "snp"})
-            temp_output = genetic_df.sel(sample=subject_list).values
+            temp_output = temp_output=genetic_df.head(100)
             genetic_data_output.append(temp_output)
 
             del genetic_df
